Pinogy Common
=============

Provides some common mixins and utilities.

Note, because this repo is private, and therefore cannot be installed directly
onto Aldryn via Pip, it can also be installed as an addon. However, installing
this won't provide anything by itself.
